@@ -9,7 +9,11 @@ from tabulate import tabulate
 from . import SQLite3toMySQL
 from .click_utils import OptionEatAll, prompt_password
 from .debug_info import info
-from .mysql_utils import MYSQL_TEXT_COLUMN_TYPES, mysql_supported_character_sets
+from .mysql_utils import (
+    MYSQL_INSERT_METHOD,
+    MYSQL_TEXT_COLUMN_TYPES,
+    mysql_supported_character_sets,
+)
 
 
 @click.command()
@@ -32,6 +36,13 @@ from .mysql_utils import MYSQL_TEXT_COLUMN_TYPES, mysql_supported_character_sets
 @click.option(
     "-X", "--without-foreign-keys", is_flag=True, help="Do not transfer foreign keys."
 )
+@click.option(
+    "-W",
+    "--ignore-duplicate-keys",
+    is_flag=True,
+    help="Ignore duplicate keys. The default behavior is to create new ones with a numerical suffix, e.g. "
+    "'exising_key' -> 'existing_key_1'",
+)
 @click.option(
     "-d", "--mysql-database", default=None, help="MySQL database name", required=True
 )
@@ -54,6 +65,20 @@ from .mysql_utils import MYSQL_TEXT_COLUMN_TYPES, mysql_supported_character_sets
 @click.option(
     "-S", "--skip-ssl", is_flag=True, help="Disable MySQL connection encryption."
 )
+@click.option(
+    "-i",
+    "--mysql-insert-method",
+    type=click.Choice(MYSQL_INSERT_METHOD, case_sensitive=False),
+    default="IGNORE",
+    help="MySQL insert method. DEFAULT will throw errors when encountering duplicate records; "
+    "UPDATE will update existing rows; IGNORE will ignore insert errors. Defaults to IGNORE.",
+)
+@click.option(
+    "-E",
+    "--mysql-truncate-tables",
+    is_flag=True,
+    help="Truncates existing tables before inserting data.",
+)
 @click.option(
     "--mysql-integer-type",
     default="INT(11)",
@@ -104,6 +129,7 @@ from .mysql_utils import MYSQL_TEXT_COLUMN_TYPES, mysql_supported_character_sets
 )
 @click.option("-l", "--log-file", type=click.Path(), help="Log file")
 @click.option("-q", "--quiet", is_flag=True, help="Quiet. Display only errors.")
+@click.option("--debug", is_flag=True, help="Debug mode. Will throw exceptions.")
 @click.version_option(
     message=tabulate(info(), headers=["software", "version"], tablefmt="github")
 )
@@ -111,6 +137,7 @@ def cli(
     sqlite_file,
     sqlite_tables,
     without_foreign_keys,
+    ignore_duplicate_keys,
     mysql_user,
     prompt_mysql_password,
     mysql_password,
@@ -118,6 +145,8 @@ def cli(
     mysql_host,
     mysql_port,
     skip_ssl,
+    mysql_insert_method,
+    mysql_truncate_tables,
     mysql_integer_type,
     mysql_string_type,
     mysql_text_type,
@@ -128,6 +157,7 @@ def cli(
     chunk,
     log_file,
     quiet,
+    debug,
 ):
     """Transfer SQLite to MySQL using the provided CLI options."""
     try:
@@ -157,11 +187,14 @@ def cli(
             mysql_host=mysql_host,
             mysql_port=mysql_port,
             mysql_ssl_disabled=skip_ssl,
+            mysql_insert_method=mysql_insert_method,
+            mysql_truncate_tables=mysql_truncate_tables,
             mysql_integer_type=mysql_integer_type,
             mysql_string_type=mysql_string_type,
             mysql_text_type=mysql_text_type,
             mysql_charset=mysql_charset.lower() if mysql_charset else "utf8mb4",
             mysql_collation=mysql_collation.lower() if mysql_collation else None,
+            ignore_duplicate_keys=ignore_duplicate_keys,
             use_fulltext=use_fulltext,
             with_rowid=with_rowid,
             chunk=chunk,
@@ -170,8 +203,12 @@ def cli(
         )
         converter.transfer()
     except KeyboardInterrupt:
+        if debug:
+            raise
         click.echo("\nProcess interrupted. Exiting...")
         sys.exit(1)
     except Exception as err:  # pylint: disable=W0703
+        if debug:
+            raise
         click.echo(err)
         sys.exit(1)
