@@ -7,6 +7,7 @@ import re
 import sqlite3
 from datetime import timedelta
 from decimal import Decimal
+from itertools import chain
 from math import ceil
 from os.path import isfile, realpath
 from sys import stdout
@@ -20,6 +21,7 @@ from sqlite3_to_mysql.sqlite_utils import (
     adapt_decimal,
     adapt_timedelta,
     convert_blob,
+    convert_date,
     convert_decimal,
     convert_timedelta,
     unicase_compare,
@@ -29,6 +31,7 @@ from .mysql_utils import (
     MYSQL_BLOB_COLUMN_TYPES,
     MYSQL_COLUMN_TYPES,
     MYSQL_COLUMN_TYPES_WITHOUT_DEFAULT,
+    MYSQL_INSERT_METHOD,
     MYSQL_TEXT_COLUMN_TYPES,
     MYSQL_TEXT_COLUMN_TYPES_WITH_JSON,
     check_mysql_fulltext_support,
@@ -93,6 +96,14 @@ class SQLite3toMySQL:
 
         self._mysql_database = str(kwargs.get("mysql_database") or "transfer")
 
+        self._mysql_insert_method = str(
+            kwargs.get("mysql_integer_type") or "IGNORE"
+        ).upper()
+        if self._mysql_insert_method not in MYSQL_INSERT_METHOD:
+            self._mysql_insert_method = "IGNORE"
+
+        self._mysql_truncate_tables = kwargs.get("mysql_truncate_tables") or False
+
         self._mysql_integer_type = str(
             kwargs.get("mysql_integer_type") or "INT(11)"
         ).upper()
@@ -117,6 +128,8 @@ class SQLite3toMySQL:
         ):
             self._mysql_collation = "utf8mb4_general_ci"
 
+        self.ignore_duplicate_keys = kwargs.get("ignore_duplicate_keys") or False
+
         self._use_fulltext = kwargs.get("use_fulltext") or False
 
         self._with_rowid = kwargs.get("with_rowid") or False
@@ -124,6 +137,7 @@ class SQLite3toMySQL:
         sqlite3.register_adapter(Decimal, adapt_decimal)
         sqlite3.register_converter("DECIMAL", convert_decimal)
         sqlite3.register_adapter(timedelta, adapt_timedelta)
+        sqlite3.register_converter("DATE", convert_date)
         sqlite3.register_converter("TIME", convert_timedelta)
 
         if six.PY2:
@@ -373,6 +387,25 @@ class SQLite3toMySQL:
             )
             raise
 
+    def _truncate_table(self, table_name):
+        self._mysql_cur.execute(
+            """
+            SELECT `TABLE_NAME`
+            FROM `INFORMATION_SCHEMA`.`TABLES`
+            WHERE `TABLE_SCHEMA` = %s
+            AND `TABLE_NAME` = %s
+            LIMIT 1
+            """,
+            (self._mysql_database, safe_identifier_length(table_name)),
+        )
+        if len(self._mysql_cur.fetchall()) > 0:
+            self._logger.info("Truncating table %s", safe_identifier_length(table_name))
+            self._mysql_cur.execute(
+                "TRUNCATE TABLE `{}`".format(
+                    safe_identifier_length(table_name),
+                ),
+            )
+
     def _add_indices(self, table_name):
         self._sqlite_cur.execute('PRAGMA table_info("{}")'.format(table_name))
         table_columns = {}
@@ -508,15 +541,29 @@ class SQLite3toMySQL:
             self._mysql.commit()
         except mysql.connector.Error as err:
             if err.errno == errorcode.ER_DUP_KEYNAME:
-                # handle a duplicate key name
-                self._add_index(
-                    table_name=table_name,
-                    index_type=index_type,
-                    index=index,
-                    index_columns=index_columns,
-                    index_infos=index_infos,
-                    index_iteration=index_iteration + 1,
-                )
+                if not self.ignore_duplicate_keys:
+                    # handle a duplicate key name
+                    self._add_index(
+                        table_name=table_name,
+                        index_type=index_type,
+                        index=index,
+                        index_columns=index_columns,
+                        index_infos=index_infos,
+                        index_iteration=index_iteration + 1,
+                    )
+                    self._logger.warning(
+                        """Duplicate key "%s" in table %s detected! Trying to create new key "%s_%s" ...""",
+                        safe_identifier_length(index["name"]),
+                        safe_identifier_length(table_name),
+                        safe_identifier_length(index["name"]),
+                        index_iteration + 1,
+                    )
+                else:
+                    self._logger.warning(
+                        """Ignoring duplicate key "%s" in table %s!""",
+                        safe_identifier_length(index["name"]),
+                        safe_identifier_length(table_name),
+                    )
             elif err.errno == errorcode.ER_BAD_FT_COLUMN:
                 # handle bad FULLTEXT index
                 self._logger.warning(
@@ -652,6 +699,10 @@ class SQLite3toMySQL:
                 # create the table
                 self._create_table(table["name"], transfer_rowid=transfer_rowid)
 
+                # truncate the table on request
+                if self._mysql_truncate_tables:
+                    self._truncate_table(table["name"])
+
                 # get the size of the data
                 self._sqlite_cur.execute(
                     'SELECT COUNT(*) AS total_records FROM "{}"'.format(table["name"])
@@ -674,15 +725,43 @@ class SQLite3toMySQL:
                         safe_identifier_length(column[0])
                         for column in self._sqlite_cur.description
                     ]
-                    sql = """
-                        INSERT IGNORE
-                        INTO `{table}` ({fields})
-                        VALUES ({placeholders})
-                    """.format(
-                        table=safe_identifier_length(table["name"]),
-                        fields=("`{}`, " * len(columns)).rstrip(" ,").format(*columns),
-                        placeholders=("%s, " * len(columns)).rstrip(" ,"),
-                    )
+                    if self._mysql_insert_method.upper() == "UPDATE":
+                        sql = """
+                            INSERT
+                            INTO `{table}` ({fields})
+                            VALUES ({placeholders}) AS `__new__`
+                            ON DUPLICATE KEY UPDATE {field_updates}
+                        """.format(
+                            table=safe_identifier_length(table["name"]),
+                            fields=("`{}`, " * len(columns))
+                            .rstrip(" ,")
+                            .format(*columns),
+                            placeholders=("%s, " * len(columns)).rstrip(" ,"),
+                            field_updates=("`{}`=`__new__`.`{}`, " * len(columns))
+                            .rstrip(" ,")
+                            .format(
+                                *list(
+                                    chain.from_iterable(
+                                        (column, column) for column in columns
+                                    )
+                                )
+                            ),
+                        )
+                    else:
+                        sql = """
+                            INSERT {ignore}
+                            INTO `{table}` ({fields})
+                            VALUES ({placeholders})
+                        """.format(
+                            ignore="IGNORE"
+                            if self._mysql_insert_method.upper() == "IGNORE"
+                            else "",
+                            table=safe_identifier_length(table["name"]),
+                            fields=("`{}`, " * len(columns))
+                            .rstrip(" ,")
+                            .format(*columns),
+                            placeholders=("%s, " * len(columns)).rstrip(" ,"),
+                        )
                     try:
                         self._transfer_table_data(sql=sql, total_records=total_records)
                     except mysql.connector.Error as err:
